@@ -21,10 +21,10 @@ Description:
 
 CVS Information:
 
-    $Source: /home/globdev/CVS/globus-packages/gass/cache_program/source/globus_gass_cache.c,v $
-    $Date: 2010/08/03 15:49:08 $
-    $Revision: 1.49 $
-    $Author: bester $
+    $Source$
+    $Date$
+    $Revision$
+    $Author$
 ******************************************************************************/
 
 /******************************************************************************
